Inmanta Reference
==================

.. welcome

Welcome to the Inmanta reference guide!

Here we explain all the features and options of Inmanta. If you're just looking to get started with
Inmanta, please check out the :doc:`../quickstart` guide.

.. toctree::

    commands
    config
    api
    modules